date_type
=========

The data contains different dates regarding each incident. The date type filter enables you to specify which
type of date to use for the query. Leaving the filter to its default value (None) will return all data. The options are:

- **start_date** - this is the start date of the incident.
- **createdAt** - this is the date at which the incident was added to the EuRepoC database.
- **updatedAt** - this is the date at which the incident was last updated in the EuRepoC database.

    Note: when specifying the start and end, the date format is `YYYY-MM-DD`.